@@ -1,4 +1,5 @@
 #!/bin/perl -w
+# $Id: check_file_age.pl,v 1.2 2003/10/21 15:56:35 tonvoon Exp $
 
 # check_file_age.pl Copyright (C) 2003 Steven Grimm <koreth-nagios@midwinter.com>
 #
@@ -54,7 +55,7 @@ GetOptions(
 	"C=f" => \$opt_C, "critical-size=f" => \$opt_C);
 
 if ($opt_V) {
-	print_revision($PROGNAME, '@NP_VERSION@');
+	print_revision($PROGNAME, '$Id: check_file_age.pl,v 1.2 2003/10/21 15:56:35 tonvoon Exp $');
 	exit $ERRORS{'OK'};
 }
 
@@ -66,14 +67,14 @@ if ($opt_h) {
 $opt_f = shift unless ($opt_f);
 
 if (! $opt_f) {
-	print "FILE_AGE UNKNOWN: No file specified\n";
+	print "No file specified\n";
 	exit $ERRORS{'UNKNOWN'};
 }
 
-# Check that file exists (can be directory or link)
-unless (-e $opt_f) {
-	print "FILE_AGE CRITICAL: File not found - $opt_f\n";
-	exit $ERRORS{'CRITICAL'};
+# Examine the file.
+unless (-f $opt_f) {
+	print "$opt_f: File not found\n";
+	exit $ERRORS{'UNKNOWN'};
 }
 
 $st = File::stat::stat($opt_f);
@@ -90,7 +91,7 @@ elsif (($opt_w and $age > $opt_w) or ($opt_W and $size < $opt_W)) {
 	$result = 'WARNING';
 }
 
-print "FILE_AGE $result: $opt_f is $age seconds old and $size bytes\n";
+print "$result - $opt_f is $age seconds old and $size bytes\n";
 exit $ERRORS{$result};
 
 sub print_usage () {
@@ -101,12 +102,12 @@ sub print_usage () {
 }
 
 sub print_help () {
-	print_revision($PROGNAME, '@NP_VERSION@');
+	print_revision($PROGNAME, '$Id: check_file_age.pl,v 1.2 2003/10/21 15:56:35 tonvoon Exp $');
 	print "Copyright (c) 2003 Steven Grimm\n\n";
 	print_usage();
 	print "\n";
-	print "  <secs>  File must be no more than this many seconds old (default: warn 240 secs, crit 600)\n";
-	print "  <size>  File must be at least this many bytes long (default: crit 0 bytes)\n";
+	print "  <secs>  File must be no more than this many seconds old\n";
+	print "  <size>  File must be at least this many bytes long\n";
 	print "\n";
 	support();
 }
