@@ -29,6 +29,7 @@
 # 
 # 11.01.2000 Version 1.0
 #
+# $Id: check_ifstatus.pl,v 1.9 2004/08/18 19:51:35 tonvoon Exp $
 
 use POSIX;
 use strict;
@@ -42,8 +43,7 @@ Getopt::Long::Configure('bundling');
 my $PROGNAME = "check_ifstatus";
 
 sub print_help ();
-sub usage ($);
-sub print_usage ();
+sub usage ();
 sub process_arguments ();
 
 
@@ -64,7 +64,7 @@ my $snmpoid=0;
 my $key=0;
 my $community = "public";
 my $maxmsgsize = 1472 ; # Net::SNMP default is 1472
-my ($seclevel, $authproto, $secname, $authpass, $privpass, $privproto, $auth, $priv, $context);
+my ($seclevel, $authproto, $secname, $authpass, $privpass, $auth, $priv, $context);
 my $port = 161;
 my @snmpoids;
 my $snmpIfAdminStatus = '1.3.6.1.2.1.2.2.1.7';
@@ -93,7 +93,6 @@ my $opt_u;
 my $opt_x ;
 my %excluded ;
 my @unused_ports ;
-my %session_opts;
 
 
 
@@ -117,15 +116,6 @@ if ($status != 0)
 
 
 alarm($timeout);
-($session, $error) = Net::SNMP->session(%session_opts);
-		
-if (!defined($session)) {
-			$state='UNKNOWN';
-			$answer=$error;
-			print ("$state: $answer\n");
-			exit $ERRORS{$state};
-}
-
 
 push(@snmpoids,$snmpIfOperStatus);
 push(@snmpoids,$snmpIfAdminStatus);
@@ -220,25 +210,19 @@ my $perfdata = sprintf("up=%d,down=%d,dormant=%d,excluded=%d,unused=%d",$ifup,$i
 print ("$state: $answer |$perfdata\n");
 exit $ERRORS{$state};
 
-sub usage($) {
-	print "$_[0]\n";
-	print_usage();
-	exit $ERRORS{"UNKNOWN"};
-}
 
-sub print_usage() {
+sub usage (){
+	printf "\nMissing arguments!\n";
 	printf "\n";
-	printf "usage: \n";
 	printf "check_ifstatus -C <READCOMMUNITY> -p <PORT> -H <HOSTNAME>\n";
 	printf "Copyright (C) 2000 Christoph Kron\n";
 	printf "Updates 5/2002 Subhendu Ghosh\n";
-	support();
 	printf "\n\n";
+	support();
+	exit $ERRORS{"UNKNOWN"};
 }
 
-sub print_help() {
-	print_revision($PROGNAME, '@NP_VERSION@');
-	print_usage();
+sub print_help (){
 	printf "check_ifstatus plugin for Nagios monitors operational \n";
 	printf "status of each network interface on the target host\n";
 	printf "\nUsage:\n";
@@ -259,20 +243,19 @@ sub print_help() {
 	printf "                     See the IANAifType-MIB for a list of interface types.\n";
 	printf "   -L (--seclevel)   choice of \"noAuthNoPriv\", \"authNoPriv\", or	\"authPriv\"\n";
 	printf "   -U (--secname)    username for SNMPv3 context\n";
-	printf "   -c (--context)    SNMPv3 context name (default is empty string)\n";
+	printf "   -c (--context)    SNMPv3 context name (default is empty	string)";
 	printf "   -A (--authpass)   authentication password (cleartext ascii or localized key\n";
-	printf "                     in hex with 0x prefix generated by using \"snmpkey\" utility\n"; 
+	printf "                     in hex with 0x prefix generated by using	\"snmpkey\" utility\n"; 
 	printf "                     auth password and authEngineID\n";
-	printf "   -a (--authproto)  Authentication protocol (MD5 or SHA1)\n";
+	printf "   -a (--authproto)  Authentication protocol ( MD5 or SHA1)\n";
 	printf "   -X (--privpass)   privacy password (cleartext ascii or localized key\n";
-	printf "                     in hex with 0x prefix generated by using \"snmpkey\" utility\n"; 
+	printf "                     in hex with 0x prefix generated by using	\"snmpkey\" utility\n"; 
 	printf "                     privacy password and authEngineID\n";
-	printf "   -P (--privproto)  privacy protocol (DES or AES; default: DES)\n";
 	printf "   -M (--maxmsgsize) Max message size - usefull only for v1 or v2c\n";
 	printf "   -t (--timeout)    seconds before the plugin times out (default=$TIMEOUT)\n";
 	printf "   -V (--version)    Plugin version\n";
 	printf "   -h (--help)       usage help \n\n";
-	print_revision($PROGNAME, '@NP_VERSION@');
+	print_revision($PROGNAME, '$Revision: 1.9 $');
 	
 }
 
@@ -287,7 +270,6 @@ sub process_arguments() {
 		"U=s" => \$secname,   "secname=s"   => \$secname,
 		"A=s" => \$authpass,  "authpass=s"  => \$authpass,
 		"X=s" => \$privpass,  "privpass=s"  => \$privpass,
-		"P=s" => \$privproto,  "privproto=s"  => \$privproto,
 		"c=s" => \$context,   "context=s"   => \$context,
 		"p=i" =>\$port, "port=i" => \$port,
 		"H=s" => \$hostname, "hostname=s" => \$hostname,
@@ -299,12 +281,11 @@ sub process_arguments() {
 		);
 		
 	if ($status == 0){
-		print_help();
+		print_help() ;
 		exit $ERRORS{'OK'};
 	}
-
 	if ($opt_V) {
-		print_revision($PROGNAME,'@NP_VERSION@');
+		print_revision($PROGNAME,'$Revision: 1.9 $ ');
 		exit $ERRORS{'OK'};
 	}
 
@@ -317,75 +298,68 @@ sub process_arguments() {
 		$timeout = $TIMEOUT;
 	}
 
-	if ($snmp_version !~ /[123]/){
-		$state='UNKNOWN';
-		print ("$state: No support for SNMP v$snmp_version yet\n");
-		exit $ERRORS{$state};
-	}
-
-	%session_opts = (
-		-hostname   => $hostname,
-		-port       => $port,
-		-version    => $snmp_version,
-		-maxmsgsize => $maxmsgsize
-	);
-
-	$session_opts{'-community'} = $community if (defined $community && $snmp_version =~ /[12]/);
-
 	if ($snmp_version =~ /3/ ) {
 		# Must define a security level even though default is noAuthNoPriv
 		# v3 requires a security username
-		if (defined $seclevel && defined $secname) {
-			$session_opts{'-username'} = $secname;
+		if (defined $seclevel  && defined $secname) {
 		
 			# Must define a security level even though defualt is noAuthNoPriv
-			unless ( grep /^$seclevel$/, qw(noAuthNoPriv authNoPriv authPriv) ) {
-				usage("Must define a valid security level even though default is noAuthNoPriv");
+			unless ($seclevel eq ('noAuthNoPriv' || 'authNoPriv' || 'authPriv' ) ) {
+				usage();
+				exit $ERRORS{"UNKNOWN"};
 			}
 			
 			# Authentication wanted
-			if ( $seclevel eq 'authNoPriv' || $seclevel eq 'authPriv' ) {
-				if (defined $authproto && $authproto ne 'MD5' && $authproto ne 'SHA1') {
-					usage("Auth protocol can be either MD5 or SHA1");
+			if ($seclevel eq ('authNoPriv' || 'authPriv') ) {
+		
+				unless ($authproto eq ('MD5' || 'SHA1') ) {
+					usage();
+					exit $ERRORS{"UNKNOWN"};
 				}
-				$session_opts{'-authprotocol'} = $authproto if(defined $authproto);
 
 				if ( !defined $authpass) {
-					usage("Auth password/key is not defined");
+					usage();
+					exit $ERRORS{"UNKNOWN"};
 				}else{
 					if ($authpass =~ /^0x/ ) {
-						$session_opts{'-authkey'} = $authpass ;
+						$auth = "-authkey => $authpass" ;
 					}else{
-						$session_opts{'-authpassword'} = $authpass ;
+						$auth = "-authpassword => $authpass";
 					}
 				}
+					
 			}
 			
 			# Privacy (DES encryption) wanted
-			if ($seclevel eq 'authPriv' ) {
+			if ($seclevel eq  'authPriv' ) {
 				if (! defined $privpass) {
-					usage("Privacy passphrase/key is not defined");
+					usage();
+					exit $ERRORS{"UNKNOWN"};
 				}else{
 					if ($privpass =~ /^0x/){
-						$session_opts{'-privkey'} = $privpass;
+						$priv = "-privkey => $privpass";
 					}else{
-						$session_opts{'-privpassword'} = $privpass;
+						$priv = "-privpassword => $privpass";
 					}
 				}
-
-				$session_opts{'-privprotocol'} = $privproto if(defined $privproto);
 			}
 
 			# Context name defined or default
+
 			unless ( defined $context) {
 				$context = "";
 			}
 		
+		
+		
 		}else {
-			usage("Security level or name is not defined");
+					usage();
+					exit $ERRORS{'UNKNOWN'}; ;
 		}
 	} # end snmpv3
 
+	# for snmp v1 & v2c we default to community = "public"
+	
 	# Excluded interfaces types (ifType) (backup interfaces, dial-on demand interfaces, PPP interfaces
 	if (defined $opt_x) {
 		my @x = split(/,/, $opt_x);
@@ -407,16 +381,79 @@ sub process_arguments() {
 	}
 
 	if (! utils::is_hostname($hostname)){
-		usage("Hostname invalid or not given");
+		usage();
 		exit $ERRORS{"UNKNOWN"};
 	}
 
+	# create SNMP session handle based on options passed.
+
+	if ( ! $snmp_version ) {
+		$snmp_version =1 ;
+	}else{
+		if ( $snmp_version =~ /[12]/ ) {
+	
+			($session, $error) = Net::SNMP->session(
+						-hostname  => $hostname,
+						-community => $community,
+						-port      => $port,
+						-version	=> $snmp_version,
+						-maxmsgsize => $maxmsgsize
+			 );
+
+		if (!defined($session)) {
+					$state='UNKNOWN';
+					$answer=$error;
+					print ("$state: $answer");
+					exit $ERRORS{$state};
+		}
+
 		
-	if ($snmp_version !~ /[123]/) {
+	}elsif ( $snmp_version =~ /3/ ) {
+
+		if ($seclevel eq 'noAuthNoPriv') {
+			($session, $error) = Net::SNMP->session(
+				-hostname  => $hostname,
+				-port      => $port,
+				-version  => $snmp_version,
+				-username => $secname,
+			);
+
+		}elsif ( $seclevel eq 'authNoPriv' ) {
+			($session, $error) = Net::SNMP->session(
+				-hostname  => $hostname,
+				-port      => $port,
+				-version  => $snmp_version,
+				-username => $secname,
+				-authprotocol => $authproto,
+				$auth
+			);	
+		}elsif ($seclevel eq 'authPriv' ) {
+			($session, $error) = Net::SNMP->session(
+				-hostname  => $hostname,
+				-port      => $port,
+				-version  => $snmp_version,
+				-username => $secname,
+				-authprotocol => $authproto,
+				$auth,
+				$priv
+			);
+		}
+					
+					
+		if (!defined($session)) {
+					$state='UNKNOWN';
+					$answer=$error;
+					print ("$state: $answer");
+					exit $ERRORS{$state};
+		}
+			
+	}else{
 		$state='UNKNOWN';
 		print ("$state: No support for SNMP v$snmp_version yet\n");
 		exit $ERRORS{$state};
 	}
+}
 
 return $ERRORS{"OK"};
+				
 }
