@@ -22,7 +22,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-# $Id: check_mailq.pl 1443 2006-07-05 13:45:57Z tonvoon $
+# $Id: check_mailq.pl,v 1.5 2005/01/03 00:59:48 opensides Exp $
 #
 ############################################################################
 
@@ -173,7 +173,7 @@ if ($mailq eq "sendmail") {
 		    # multi queue: one for each queue. overwrite on multi queue below
 	  	  $msg_q = $1 ;
 			}
-		} elsif (/^\s+Total\sRequests:\s(\d+)$/i) {
+		} elsif (/^\s+Total\sRequests:\s(\d+)$/) {
 			print "$utils::PATH_TO_MAILQ = $_ \n" if $verbose ;
 			#
 			# multi queue: last line
@@ -186,10 +186,12 @@ if ($mailq eq "sendmail") {
 	## close mailq
 
 	close (MAILQ); 
-
+	# declare an error if we also get a non-zero return code from mailq
+	# unless already set to critical
 	if ( $? ) {
-		print "CRITICAL: Error code ".($?>>8)." returned from $utils::PATH_TO_MAILQ",$/;
-		exit $ERRORS{CRITICAL};
+		$state = $state == $ERRORS{"CRITICAL"} ? $ERRORS{"CRITICAL"} : $ERRORS{"WARNING"}  ;
+		print "STDERR $?: $!\n" if $verbose;
+		$msg = "$state: (stderr)\n";
 	}
 
 	## shut off the alarm
@@ -316,10 +318,12 @@ elsif ( $mailq eq "postfix" ) {
 
         # close qmail-qstat
         close MAILQ;
-
+        # declare an error if we also get a non-zero return code from mailq
+        # unless already set to critical
         if ( $? ) {
-		print "CRITICAL: Error code ".($?>>8)." returned from $utils::PATH_TO_MAILQ",$/;
-		exit $ERRORS{CRITICAL};
+                $state = $state == $ERRORS{"CRITICAL"} ? $ERRORS{"CRITICAL"} : $ERRORS{"WARNING"}  ;
+                print "STDERR $?: $!\n" if $verbose;
+                $msg = "$state: (stderr)\n";
         }
 
         ## shut off the alarm
@@ -397,10 +401,12 @@ elsif ( $mailq eq "qmail" ) {
 
 	# close qmail-qstat
 	close MAILQ;
-
+	# declare an error if we also get a non-zero return code from mailq
+	# unless already set to critical
 	if ( $? ) {
-		print "CRITICAL: Error code ".($?>>8)." returned from $utils::PATH_TO_MAILQ",$/;
-		exit $ERRORS{CRITICAL};
+		$state = $state == $ERRORS{"CRITICAL"} ? $ERRORS{"CRITICAL"} : $ERRORS{"WARNING"}  ;
+		print "STDERR $?: $!\n" if $verbose;
+		$msg = "$state: (stderr)\n";
 	}
 
 	## shut off the alarm
@@ -484,11 +490,6 @@ elsif ( $mailq eq "exim" ) {
 	    }
 	}
 	close(MAILQ) ;
-
-	if ( $? ) {
-		print "CRITICAL: Error code ".($?>>8)." returned from $utils::PATH_TO_MAILQ",$/;
-		exit $ERRORS{CRITICAL};
-	}
 	if ($msg_q < $opt_w) {
 		$msg = "OK: mailq ($msg_q) is below threshold ($opt_w/$opt_c)";
 		$state = $ERRORS{'OK'};
@@ -522,7 +523,7 @@ sub process_arguments(){
 		 );
 
 	if ($opt_V) {
-		print_revision($PROGNAME,'$Revision: 1443 $ ');
+		print_revision($PROGNAME,'$Revision: 1.5 $ ');
 		exit $ERRORS{'OK'};
 	}
 
@@ -580,7 +581,7 @@ sub print_usage () {
 }
 
 sub print_help () {
-	print_revision($PROGNAME,'$Revision: 1443 $');
+	print_revision($PROGNAME,'$Revision: 1.5 $');
 	print "Copyright (c) 2002 Subhendu Ghosh/Carlos Canau/Benjamin Schmid\n";
 	print "\n";
 	print_usage();
