@@ -1,86 +1,44 @@
 /******************************************************************************
- *
- * Program: PostgreSQL plugin for Nagios
- * License: GPL
- *
- * License Information:
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- *
- * $Id: check_pgsql.c,v 1.7 2003/02/18 23:00:18 kdebisschop Exp $
- *
+
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by
+ the Free Software Foundation; either version 2 of the License, or
+ (at your option) any later version.
+
+ This program is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ GNU General Public License for more details.
+
+ You should have received a copy of the GNU General Public License
+ along with this program; if not, write to the Free Software
+ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
+ $Id: check_pgsql.c,v 1.31 2004/12/25 23:17:44 opensides Exp $
+ 
  *****************************************************************************/
 
 const char *progname = "check_pgsql";
-#define REVISION "$Revision: 1.7 $"
-#define COPYRIGHT "1999-2001"
-#define AUTHOR "Karl DeBisschop"
-#define EMAIL "kdebisschop@users.sourceforge.net"
-#define SUMMARY "Tests to see if a PostgreSQL DBMS is accepting connections.\n"
+const char *revision = "$Revision: 1.31 $";
+const char *copyright = "1999-2004";
+const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
-#define OPTIONS "[-c critical_time] [-w warning_time] [-t timeout] [-H host]\n\
-             [-P port] [-d database] [-l logname] [-p password]"
+#include "common.h"
+#include "utils.h"
 
-#define LONGOPTIONS "\
-  -c, --critical=INTEGER\n\
-    Exit STATE_CRITICAL if connection time exceeds threshold (default: %d)\n\
-  -w, --warning=INTEGER\n\
-    Exit STATE_WARNING if connection time exceeds threshold (default: %d)\n\
-  -t, --timeout=INTEGER\n\
-    Terminate test if timeout limit is exceeded (default: %d)\n\
-  -H, --hostname=STRING\n\
-    Name or numeric IP address of machine running backend\n\
-  -P, --port=INTEGER\n\
-    Port running backend (default: %d)\n\
-  -d, --database=STRING\n\
-    Database to check (default: %s)\n\
-  -l, --logname = STRING\n\
-    Login name of user\n\
-  -p, --password = STRING\n\
-    Password (BIG SECURITY ISSUE)\n"
-
-#define DESCRIPTION "All parameters are optional.\n\
-\n\
-This plugin tests a PostgreSQL DBMS to determine whether it is active and\n\
-accepting queries. In its current operation, it simply connects to the\n\
-specified database, and then disconnects. If no database is specified, it\n\
-connects to the template1 database, which is present in every functioning \n\
-PostgreSQL DBMS.\n\
-\n\
-The plugin will connect to a local postmaster if no host is specified. To\n\
-connect to a remote host, be sure that the remote postmaster accepts TCP/IP\n\
-connections (start the postmaster with the -i option).\n\
-\n\
-Typically, the nagios user (unless the --logname option is used) should be\n\
-able to connect to the database without a password. The plugin can also send\n\
-a password, but no effort is made to obsure or encrypt the password.\n"
+#include "netutils.h"
+#include <libpq-fe.h>
 
 #define DEFAULT_DB "template1"
 #define DEFAULT_HOST "127.0.0.1"
+
 enum {
 	DEFAULT_PORT = 5432,
 	DEFAULT_WARN = 2,
-	DEFAULT_CRIT = 8,
-	DEFAULT_TIMEOUT = 30
+	DEFAULT_CRIT = 8
 };
 
-#include "config.h"
-#include "common.h"
-#include "utils.h"
-#include <netdb.h>
-#include <libpq-fe.h>
+
 
 int process_arguments (int, char **);
 int validate_arguments (void);
@@ -97,12 +55,12 @@ char *pgtty = NULL;
 char dbName[NAMEDATALEN] = DEFAULT_DB;
 char *pguser = NULL;
 char *pgpasswd = NULL;
-int twarn = DEFAULT_WARN;
-int tcrit = DEFAULT_CRIT;
+double twarn = (double)DEFAULT_WARN;
+double tcrit = (double)DEFAULT_CRIT;
 
 PGconn *conn;
 /*PGresult   *res;*/
-
+
 
 /******************************************************************************
 
@@ -158,10 +116,13 @@ Please note that all tags must be lowercase to use the DocBook XML DTD.
 -@@
 ******************************************************************************/
 
+
+
 int
 main (int argc, char **argv)
 {
 	int elapsed_time;
+	int status = STATE_UNKNOWN;
 
 	/* begin, by setting the parameters for a backend connection if the
 	 * parameters are null, then the system will try to use reasonable
@@ -171,13 +132,16 @@ main (int argc, char **argv)
 	pgoptions = NULL;  /* special options to start up the backend server */
 	pgtty = NULL;      /* debugging tty for the backend server */
 
+	setlocale (LC_ALL, "");
+	bindtextdomain (PACKAGE, LOCALEDIR);
+	textdomain (PACKAGE);
+
 	if (process_arguments (argc, argv) == ERROR)
-		usage ("Could not parse arguments");
+		usage4 (_("Could not parse arguments"));
 
 	/* Set signal handling and alarm */
 	if (signal (SIGALRM, timeout_alarm_handler) == SIG_ERR) {
-		printf ("Cannot catch SIGALRM");
-		return STATE_UNKNOWN;
+		usage4 (_("Cannot catch SIGALRM"));
 	}
 	alarm (timeout_interval);
 
@@ -190,55 +154,28 @@ main (int argc, char **argv)
 
 	/* check to see that the backend connection was successfully made */
 	if (PQstatus (conn) == CONNECTION_BAD) {
-		printf ("PGSQL: CRITICAL - no connection to '%s' (%s).\n", dbName,
-						PQerrorMessage (conn));
+		printf (_("CRITICAL - no connection to '%s' (%s).\n"),
+		        dbName,	PQerrorMessage (conn));
 		PQfinish (conn);
 		return STATE_CRITICAL;
 	}
 	else if (elapsed_time > tcrit) {
-		PQfinish (conn);
-		printf ("PGSQL: CRITICAL - database %s (%d sec.)\n", dbName,
-						elapsed_time);
-		return STATE_CRITICAL;
+		status = STATE_CRITICAL;
 	}
 	else if (elapsed_time > twarn) {
-		PQfinish (conn);
-		printf ("PGSQL: WARNING - database %s (%d sec.)\n", dbName, elapsed_time);
-		return STATE_WARNING;
+		status = STATE_WARNING;
 	}
 	else {
-		PQfinish (conn);
-		printf ("PGSQL: ok - database %s (%d sec.)\n", dbName, elapsed_time);
-		return STATE_OK;
+		status = STATE_OK;
 	}
-}
-
-
-
-
-void
-print_help (void)
-{
-	print_revision (progname, REVISION);
-	printf
-		("Copyright (c) %s %s <%s>\n\n%s\n",
-		 COPYRIGHT, AUTHOR, EMAIL, SUMMARY);
-	print_usage ();
-	printf
-		("\nOptions:\n" LONGOPTIONS "\n" DESCRIPTION "\n", 
-		 DEFAULT_WARN, DEFAULT_CRIT, DEFAULT_TIMEOUT, DEFAULT_PORT, DEFAULT_DB);
-	support ();
+	PQfinish (conn);
+	printf (_(" %s - database %s (%d sec.)|%s\n"), 
+	        state_text(status), dbName, elapsed_time,
+	        fperfdata("time", elapsed_time, "s",
+	                 (int)twarn, twarn, (int)tcrit, tcrit, TRUE, 0, FALSE,0));
+	return status;
 }
 
-void
-print_usage (void)
-{
-	printf ("Usage:\n" " %s %s\n"
-					" %s (-h | --help) for detailed help\n"
-					" %s (-V | --version) for version information\n",
-					progname, OPTIONS, progname, progname);
-}
-
 
 
 /* process command-line arguments */
@@ -247,9 +184,8 @@ process_arguments (int argc, char **argv)
 {
 	int c;
 
-#ifdef HAVE_GETOPT_H
-	int option_index = 0;
-	static struct option long_options[] = {
+	int option = 0;
+	static struct option longopts[] = {
 		{"help", no_argument, 0, 'h'},
 		{"version", no_argument, 0, 'V'},
 		{"timeout", required_argument, 0, 't'},
@@ -263,62 +199,64 @@ process_arguments (int argc, char **argv)
 		{"database", required_argument, 0, 'd'},
 		{0, 0, 0, 0}
 	};
-#endif
 
 	while (1) {
-#ifdef HAVE_GETOPT_H
 		c = getopt_long (argc, argv, "hVt:c:w:H:P:d:l:p:a:",
-		                 long_options, &option_index);
-#else
-		c = getopt (argc, argv, "hVt:c:w:H:P:d:l:p:a:");
-#endif
+		                 longopts, &option);
+
 		if (c == EOF)
 			break;
 
 		switch (c) {
 		case '?':     /* usage */
-			usage3 ("Unknown argument", optopt);
+			usage2 (_("Unknown argument"), optarg);
 		case 'h':     /* help */
 			print_help ();
 			exit (STATE_OK);
 		case 'V':     /* version */
-			print_revision (progname, REVISION);
+			print_revision (progname, revision);
 			exit (STATE_OK);
 		case 't':     /* timeout period */
 			if (!is_integer (optarg))
-				usage2 ("Timeout Interval must be an integer", optarg);
-			timeout_interval = atoi (optarg);
+				usage2 (_("Timeout interval must be a positive integer"), optarg);
+			else
+				timeout_interval = atoi (optarg);
 			break;
 		case 'c':     /* critical time threshold */
-			if (!is_integer (optarg))
-				usage2 ("Invalid critical threshold", optarg);
-			tcrit = atoi (optarg);
+			if (!is_nonnegative (optarg))
+				usage2 (_("Critical threshold must be a positive integer"), optarg);
+			else
+				tcrit = strtod (optarg, NULL);
 			break;
 		case 'w':     /* warning time threshold */
-			if (!is_integer (optarg))
-				usage2 ("Invalid critical threshold", optarg);
-			twarn = atoi (optarg);
+			if (!is_nonnegative (optarg))
+				usage2 (_("Warning threshold must be a positive integer"), optarg);
+			else
+				twarn = strtod (optarg, NULL);
 			break;
 		case 'H':     /* host */
 			if (!is_host (optarg))
-				usage2 ("You gave an invalid host name", optarg);
-			pghost = optarg;
+				usage2 (_("Invalid hostname/address"), optarg);
+			else
+				pghost = optarg;
 			break;
 		case 'P':     /* port */
 			if (!is_integer (optarg))
-				usage2 ("Port must be an integer", optarg);
-			pgport = optarg;
+				usage2 (_("Port must be a positive integer"), optarg);
+			else
+				pgport = optarg;
 			break;
 		case 'd':     /* database name */
-			if (!is_pg_dbname (optarg))
-				usage2 ("Database name is not valid", optarg);
-			strncpy (dbName, optarg, NAMEDATALEN - 1);
-			dbName[NAMEDATALEN - 1] = 0;
+			if (!is_pg_dbname (optarg)) /* checks length and valid chars */
+				usage2 (_("Database name is not valid"), optarg);
+			else /* we know length, and know optarg is terminated, so us strcpy */
+				strcpy (dbName, optarg);
 			break;
 		case 'l':     /* login name */
 			if (!is_pg_logname (optarg))
-				usage2 ("user name is not valid", optarg);
-			pguser = optarg;
+				usage2 (_("User name is not valid"), optarg);
+			else
+				pguser = optarg;
 			break;
 		case 'p':     /* authentication password */
 		case 'a':
@@ -351,12 +289,13 @@ first character cannot be a number, however.</para>
 -@@
 ******************************************************************************/
 
+
+
 int
 validate_arguments ()
 {
 	return OK;
 }
-
 
 
 /******************************************************************************
@@ -379,6 +318,8 @@ first character cannot be a number, however.</para>
 -@@
 ******************************************************************************/
 
+
+
 int
 is_pg_dbname (char *dbname)
 {
@@ -419,6 +360,8 @@ should be added.</para>
 -@@
 ******************************************************************************/
 
+
+
 int
 is_pg_logname (char *username)
 {
@@ -434,3 +377,69 @@ is_pg_logname (char *username)
 </article>
 -@@
 ******************************************************************************/
+
+
+
+void
+print_help (void)
+{
+	char *myport;
+
+	asprintf (&myport, "%d", DEFAULT_PORT);
+
+	print_revision (progname, revision);
+
+	printf (COPYRIGHT, copyright, email);
+
+	printf (_("Test whether a PostgreSQL Database is accepting connections.\n\n"));
+
+	print_usage ();
+
+	printf (_(UT_HELP_VRSN));
+
+	printf (_(UT_HOST_PORT), 'P', myport);
+
+	printf (_(UT_IPv46));
+
+	printf (_("\
+  -d, --database=STRING\n\
+    Database to check (default: %s)\n\
+  -l, --logname = STRING\n\
+    Login name of user\n\
+  -p, --password = STRING\n\
+    Password (BIG SECURITY ISSUE)\n"), DEFAULT_DB);
+
+	printf (_(UT_WARN_CRIT));
+
+	printf (_(UT_TIMEOUT), DEFAULT_SOCKET_TIMEOUT);
+
+	printf (_(UT_VERBOSE));
+
+	printf (_("\nAll parameters are optional.\n\
+\n\
+This plugin tests a PostgreSQL DBMS to determine whether it is active and\n\
+accepting queries. In its current operation, it simply connects to the\n\
+specified database, and then disconnects. If no database is specified, it\n\
+connects to the template1 database, which is present in every functioning \n\
+PostgreSQL DBMS.\n"));
+	printf (_("\n\
+The plugin will connect to a local postmaster if no host is specified. To\n\
+connect to a remote host, be sure that the remote postmaster accepts TCP/IP\n\
+connections (start the postmaster with the -i option).\n"));
+	printf (_("\n\
+Typically, the nagios user (unless the --logname option is used) should be\n\
+able to connect to the database without a password. The plugin can also send\n\
+a password, but no effort is made to obsure or encrypt the password.\n"));
+
+	printf (_(UT_SUPPORT));
+}
+
+
+
+void
+print_usage (void)
+{
+	printf ("\
+Usage: %s [-H <host>] [-P <port>] [-c <critical time>] [-w <warning time>]\n\
+                  [-t <timeout>] [-d <database>] [-l <logname>] [-p <password>]\n", progname);
+}
