@@ -1,86 +1,71 @@
-/*****************************************************************************
-*
-* CHECK_REAL.C
-*
-* Program: RealMedia plugin for Nagios
-* License: GPL
-* Copyright (c) 1999 Pedro Leite (leite@cic.ua.pt)
-*
-* Based on CHECK_HTTP.C
-* Copyright (c) 1999 Ethan Galstad (nagios@nagios.org)
-*
-* Last Modified: $Date: 2003/06/07 00:46:41 $
-*
-* Command line: CHECK_REAL <host_address> [-e expect] [-u url] [-p port]
-*                          [-hn host_name] [-wt warn_time] [-ct crit_time]
-*                          [-to to_sec]
-*
-* Description:
-*
-* This plugin will attempt to open an RTSP connection with the host.
-* Successul connects return STATE_OK, refusals and timeouts return
-* STATE_CRITICAL, other errors return STATE_UNKNOWN.  Successful connects,
-* but incorrect reponse messages from the host result in STATE_WARNING return
-* values.  If you are checking a virtual server that uses "host headers"you
-* must supply the FQDN (fully qualified domain name) as the [host_name]
-* argument.
-*
-* License Information:
-*
-* This program is free software; you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation; either version 2 of the License, or
-* (at your option) any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program; if not, write to the Free Software
-* Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-*
-****************************************************************************/
+/******************************************************************************
+
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by
+ the Free Software Foundation; either version 2 of the License, or
+ (at your option) any later version.
+
+ This program is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ GNU General Public License for more details.
+
+ You should have received a copy of the GNU General Public License
+ along with this program; if not, write to the Free Software
+ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
+ $Id: check_real.c,v 1.25 2004/12/25 23:17:44 opensides Exp $
+ 
+******************************************************************************/
+
+const char *progname = "check_real";
+const char *revision = "$Revision: 1.25 $";
+const char *copyright = "2000-2004";
+const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
-#include "config.h"
 #include "common.h"
 #include "netutils.h"
 #include "utils.h"
 
-const char *progname = "check_real";
+enum {
+	PORT	= 554
+};
 
-#define PORT	554
 #define EXPECT	"RTSP/1."
 #define URL	""
 
 int process_arguments (int, char **);
 int validate_arguments (void);
-int check_disk (int usp, int free_disk);
 void print_help (void);
 void print_usage (void);
 
 int server_port = PORT;
-char *server_address = "";
-char *host_name = "";
+char *server_address;
+char *host_name;
 char *server_url = NULL;
-char *server_expect = EXPECT;
+char *server_expect;
 int warning_time = 0;
 int check_warning_time = FALSE;
 int critical_time = 0;
 int check_critical_time = FALSE;
 int verbose = FALSE;
 
+
+
 int
 main (int argc, char **argv)
 {
 	int sd;
-	int result;
+	int result = STATE_UNKNOWN;
 	char buffer[MAX_INPUT_BUFFER];
 	char *status_line = NULL;
 
-	if (process_arguments (argc, argv) != OK)
-		usage ("Invalid command arguments supplied\n");
+	setlocale (LC_ALL, "");
+	bindtextdomain (PACKAGE, LOCALEDIR);
+	textdomain (PACKAGE);
+
+	if (process_arguments (argc, argv) == ERROR)
+		usage4 (_("Could not parse arguments"));
 
 	/* initialize alarm signal handling */
 	signal (SIGALRM, socket_timeout_alarm_handler);
@@ -91,7 +76,7 @@ main (int argc, char **argv)
 
 	/* try to connect to the host at the given port number */
 	if (my_tcp_connect (server_address, server_port, &sd) != STATE_OK)
-		terminate (STATE_CRITICAL, "Unable to connect to %s on port %d\n",
+		die (STATE_CRITICAL, _("Unable to connect to %s on port %d\n"),
 							 server_address, server_port);
 
 	/* Part I - Server Check */
@@ -113,14 +98,14 @@ main (int argc, char **argv)
 
 	/* return a CRITICAL status if we couldn't read any data */
 	if (result == -1)
-		terminate (STATE_CRITICAL, "No data received from %s\n", host_name);
+		die (STATE_CRITICAL, _("No data received from %s\n"), host_name);
 
 	/* make sure we find the response we are looking for */
 	if (!strstr (buffer, server_expect)) {
 		if (server_port == PORT)
-			printf ("Invalid REAL response received from host\n");
+			printf (_("Invalid REAL response received from host\n"));
 		else
-			printf ("Invalid REAL response received from host on port %d\n",
+			printf (_("Invalid REAL response received from host on port %d\n"),
 							server_port);
 	}
 	else {
@@ -162,7 +147,7 @@ main (int argc, char **argv)
 	}
 
 	/* Part II - Check stream exists and is ok */
-	if ((result == STATE_OK)&& (server_url != NULL) ) {
+	if ((result == STATE_OK )&& (server_url != NULL) ) {
 
 		/* Part I - Server Check */
 
@@ -184,16 +169,16 @@ main (int argc, char **argv)
 
 		/* return a CRITICAL status if we couldn't read any data */
 		if (result == -1) {
-			printf ("No data received from host\n");
+			printf (_("No data received from host\n"));
 			result = STATE_CRITICAL;
 		}
 		else {
 			/* make sure we find the response we are looking for */
 			if (!strstr (buffer, server_expect)) {
 				if (server_port == PORT)
-					printf ("Invalid REAL response received from host\n");
+					printf (_("Invalid REAL response received from host\n"));
 				else
-					printf ("Invalid REAL response received from host on port %d\n",
+					printf (_("Invalid REAL response received from host on port %d\n"),
 									server_port);
 			}
 			else {
@@ -247,8 +232,8 @@ main (int argc, char **argv)
 				STATE_WARNING;
 
 		/* Put some HTML in here to create a dynamic link */
-		printf ("REAL %s - %d second response time\n",
-						(result == STATE_OK) ? "ok" : "problem",
+		printf (_("REAL %s - %d second response time\n"),
+						state_text (result),
 						(int) (end_time - start_time));
 	}
 	else
@@ -265,18 +250,14 @@ main (int argc, char **argv)
 
 
 
-
-
-
 /* process command-line arguments */
 int
 process_arguments (int argc, char **argv)
 {
 	int c;
 
-#ifdef HAVE_GETOPT_H
-	int option_index = 0;
-	static struct option long_options[] = {
+	int option = 0;
+	static struct option longopts[] = {
 		{"hostname", required_argument, 0, 'H'},
 		{"IPaddress", required_argument, 0, 'I'},
 		{"expect", required_argument, 0, 'e'},
@@ -290,7 +271,6 @@ process_arguments (int argc, char **argv)
 		{"help", no_argument, 0, 'h'},
 		{0, 0, 0, 0}
 	};
-#endif
 
 	if (argc < 2)
 		return ERROR;
@@ -305,13 +285,8 @@ process_arguments (int argc, char **argv)
 	}
 
 	while (1) {
-#ifdef HAVE_GETOPT_H
-		c =
-			getopt_long (argc, argv, "+hVI:H:e:u:p:w:c:t:", long_options,
-									 &option_index);
-#else
-		c = getopt (argc, argv, "+?hVI:H:e:u:p:w:c:t");
-#endif
+		c = getopt_long (argc, argv, "+hVI:H:e:u:p:w:c:t:", longopts,
+									 &option);
 
 		if (c == -1 || c == EOF)
 			break;
@@ -319,12 +294,12 @@ process_arguments (int argc, char **argv)
 		switch (c) {
 		case 'I':									/* hostname */
 		case 'H':									/* hostname */
-			if (is_host (optarg)) {
+			if (server_address)
+				break;
+			else if (is_host (optarg))
 				server_address = optarg;
-			}
-			else {
-				usage ("Invalid host name\n");
-			}
+			else
+				usage2 (_("Invalid hostname/address"), optarg);
 			break;
 		case 'e':									/* string to expect in response header */
 			server_expect = optarg;
@@ -337,7 +312,7 @@ process_arguments (int argc, char **argv)
 				server_port = atoi (optarg);
 			}
 			else {
-				usage ("Server port must be a positive integer\n");
+				usage4 (_("Port must be a positive integer"));
 			}
 			break;
 		case 'w':									/* warning time threshold */
@@ -346,7 +321,7 @@ process_arguments (int argc, char **argv)
 				check_warning_time = TRUE;
 			}
 			else {
-				usage ("Warning time must be a nonnegative integer\n");
+				usage4 (_("Warning time must be a positive integer"));
 			}
 			break;
 		case 'c':									/* critical time threshold */
@@ -355,7 +330,7 @@ process_arguments (int argc, char **argv)
 				check_critical_time = TRUE;
 			}
 			else {
-				usage ("Critical time must be a nonnegative integer\n");
+				usage4 (_("Critical time must be a positive integer"));
 			}
 			break;
 		case 'v':									/* verbose */
@@ -366,43 +341,44 @@ process_arguments (int argc, char **argv)
 				socket_timeout = atoi (optarg);
 			}
 			else {
-				usage ("Time interval must be a nonnegative integer\n");
+				usage4 (_("Timeout interval must be a positive integer"));
 			}
 			break;
 		case 'V':									/* version */
-			print_revision (progname, "$Revision: 1.4.2.2 $");
+			print_revision (progname, revision);
 			exit (STATE_OK);
 		case 'h':									/* help */
 			print_help ();
 			exit (STATE_OK);
-		case '?':									/* help */
-			usage ("Invalid argument\n");
+		case '?':									/* usage */
+			usage2 (_("Unknown argument"), optarg);
 		}
 	}
 
 	c = optind;
-	if (strlen(server_address)==0 && argc>c) {
+	if (server_address==NULL && argc>c) {
 		if (is_host (argv[c])) {
 			server_address = argv[c++];
 		}
 		else {
-			usage ("Invalid host name");
+			usage2 (_("Invalid hostname/address"), argv[c]);
 		}
 	}
 
-	if (strlen(server_address) == 0)
-		usage ("You must provide a server to check\n");
+	if (server_address==NULL)
+		usage4 (_("You must provide a server to check"));
 
-	if (strlen(host_name) == 0)
-		asprintf (&host_name, "%s", server_address);
+	if (host_name==NULL)
+		host_name = strdup (server_address);
+
+	if (server_expect == NULL)
+		server_expect = strdup(EXPECT);
 
 	return validate_arguments ();
 }
 
 
 
-
-
 int
 validate_arguments (void)
 {
@@ -411,54 +387,54 @@ validate_arguments (void)
 
 
 
-
-
 void
 print_help (void)
 {
-	print_revision (progname, "$Revision: 1.4.2.2 $");
-	printf
-		("Copyright (c) 2000 Pedro Leite (leite@cic.ua.pt)/Karl DeBisschop\n\n"
-		 "This plugin tests the REAL service on the specified host.\n\n");
+	char *myport;
+	asprintf (&myport, "%d", PORT);
+
+	print_revision (progname, revision);
+
+	printf ("Copyright (c) 1999 Pedro Leite <leite@cic.ua.pt>\n");
+	printf (COPYRIGHT, copyright, email);
+
+	printf (_("This plugin tests the REAL service on the specified host.\n\n"));
+
 	print_usage ();
-	printf
-		("\nOptions:\n"
-		 " -H, --hostname=STRING or IPADDRESS\n"
-		 "   Check this server on the indicated host\n"
-		 " -I, --IPaddress=STRING or IPADDRESS\n"
-		 "   Check server at this host address\n"
-		 " -p, --port=INTEGER\n"
-		 "   Make connection on the indicated port (default: %d)\n"
-		 " -u, --url=STRING\n"
-		 "   Connect to this url\n"
-		 " -e, --expect=STRING\n"
-		 "   String to expect in first line of server response (default: %s)\n"
-		 " -w, --warning=INTEGER\n"
-		 "   Seconds necessary to result in a warning status\n"
-		 " -c, --critical=INTEGER\n"
-		 "   Seconds necessary to result in a critical status\n"
-		 " -t, --timeout=INTEGER\n"
-		 "   Seconds before connection attempt times out (default: %d)\n"
-		 " -v, --verbose\n"
-		 "   Print extra information (command-line use only)\n"
-		 " -h, --help\n"
-		 "   Print detailed help screen\n"
-		 " -V, --version\n"
-		 "   Print version information\n\n",
-		 PORT, EXPECT, DEFAULT_SOCKET_TIMEOUT);
-	support ();
+
+	printf (_(UT_HELP_VRSN));
+
+	printf (_(UT_HOST_PORT), 'p', myport);
+
+	printf (_("\
+ -u, --url=STRING\n\
+   Connect to this url\n\
+ -e, --expect=STRING\n\
+   String to expect in first line of server response (default: %s)\n"),
+	       EXPECT);
+
+	printf (_(UT_WARN_CRIT));
+
+	printf (_(UT_TIMEOUT), DEFAULT_SOCKET_TIMEOUT);
+
+	printf (_(UT_VERBOSE));
+
+	printf(_("\
+This plugin will attempt to open an RTSP connection with the host.\n\
+Successul connects return STATE_OK, refusals and timeouts return\n\
+STATE_CRITICAL, other errors return STATE_UNKNOWN.  Successful connects,\n\
+but incorrect reponse messages from the host result in STATE_WARNING return\n\
+values."));
+
+	printf (_(UT_SUPPORT));
 }
 
 
 
-
-
 void
 print_usage (void)
 {
-	printf
-		("Usage: %s -H host [-e expect] [-p port] [-w warn] [-c crit]\n"
-		 "            [-t timeout] [-v]\n"
-		 "       %s --help\n"
-		 "       %s --version\n", progname, progname, progname);
+	printf ("\
+Usage: %s -H host [-e expect] [-p port] [-w warn] [-c crit]\n\
+                  [-t timeout] [-v]\n", progname);
 }
