@@ -1,126 +1,42 @@
 /******************************************************************************
- *
- * Program: SNMP plugin for Nagios
- * License: GPL
- *
- * License Information:
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- *
- *./plugins/check_snmp 127.0.0.1 -c public -o .1.3.6.1.4.1.2021.9.1.2.1
- *
- *****************************************************************************/
+
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by
+ the Free Software Foundation; either version 2 of the License, or
+ (at your option) any later version.
+
+ This program is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ GNU General Public License for more details.
+
+ You should have received a copy of the GNU General Public License
+ along with this program; if not, write to the Free Software
+ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
+ $Id: check_snmp.c,v 1.53 2005/01/21 01:03:56 harpermann Exp $
+ 
+******************************************************************************/
 
 const char *progname = "check_snmp";
-#define REVISION "$Revision: 1.24.2.2 $"
-#define COPYRIGHT "1999-2002"
-#define AUTHOR "Ethan Galstad"
-#define EMAIL "nagios@nagios.org"
-#define SUMMARY "Check status of remote machines using SNMP.\n"
-
-#define OPTIONS "\
--H <ip_address> -o <OID> [-w warn_range] [-c crit_range] \n\
-          [-C community] [-s string] [-r regex] [-R regexi] [-t timeout]\n\
-          [-l label] [-u units] [-p port-number] [-d delimiter]\n\
-          [-D output-delimiter] [-m miblist] [-P snmp version]\n\
-          [-L seclevel] [-U secname] [-a authproto] [-A authpasswd]\n\
-          [-X privpasswd]\n"
-
-#define LONGOPTIONS "\
- -H, --hostname=HOST\n\
-    Name or IP address of the device you wish to query\n\
- -o, --oid=OID(s)\n\
-    Object identifier(s) whose value you wish to query\n\
- -w, --warning=INTEGER_RANGE(s)\n\
-    Range(s) which will not result in a WARNING status\n\
- -c, --critical=INTEGER_RANGE(s)\n\
-    Range(s) which will not result in a CRITICAL status\n\
- -C, --community=STRING\n\
-    Optional community string for SNMP communication\n\
-    (default is \"%s\")\n\
- -u, --units=STRING\n\
-    Units label(s) for output data (e.g., 'sec.').\n\
- -p, --port=STRING\n\
-    UDP port number target is listening on. Default is \"%s\"\n\
- -P, --protocol=[1|3]\n\
-    SNMP protocol version\n\
- -L, --seclevel=[noAuthNoPriv|authNoPriv|authPriv]\n\
-    SNMPv3 securityLevel\n\
- -U, --secname=USERNAME\n\
-    SNMPv3 username\n\
- -a, --authproto=[MD5|SHA]\n\
-    SNMPv3 auth proto\n\
- -A, --authpassword=PASSWORD\n\
-    SNMPv3 authentication password\n\
- -X, --privpasswd=PASSWORD\n\
-    SNMPv3 crypt passwd (DES)\n\
- -d, --delimiter=STRING\n\
-    Delimiter to use when parsing returned data. Default is \"%s\"\n\
-    Any data on the right hand side of the delimiter is considered\n\
-    to be the data that should be used in the evaluation.\n\
- -t, --timeout=INTEGER\n\
-    Seconds to wait before plugin times out (see also nagios server timeout).\n\
-    Default is %d seconds\n\
- -D, --output-delimiter=STRING\n\
-    Separates output on multiple OID requests\n\
- -s, --string=STRING\n\
-    Return OK state (for that OID) if STRING is an exact match\n\
- -r, --ereg=REGEX\n\
-    Return OK state (for that OID) if extended regular expression REGEX matches\n\
- -R, --eregi=REGEX\n\
-    Return OK state (for that OID) if case-insensitive extended REGEX matches\n\
- -l, --label=STRING\n\
-    Prefix label for output from plugin (default -s 'SNMP')\n\
- -v, --verbose\n\
-    Debugging the output\n\
- -m, --miblist=STRING\n\
-    List of MIBS to be loaded (default = ALL)\n"
-
-#define NOTES "\
-- This plugin uses the 'snmpget' command included with the NET-SNMP package.\n\
-  If you don't have the package installed, you will need to download it from\n\
-  http://net-snmp.sourceforge.net before you can use this plugin.\n\
-- Multiple OIDs may be indicated by a comma- or space-delimited list (lists with\n\
-  internal spaces must be quoted) [max 8 OIDs]\n\
-- Ranges are inclusive and are indicated with colons. When specified as\n\
-  'min:max' a STATE_OK will be returned if the result is within the indicated\n\
-  range or is equal to the upper or lower bound. A non-OK state will be\n\
-  returned if the result is outside the specified range.\n\
-- If specified in the order 'max:min' a non-OK state will be returned if the\n\
-  result is within the (inclusive) range.\n\
-- Upper or lower bounds may be omitted to skip checking the respective limit.\n\
-- Bare integers are interpreted as upper limits.\n\
-- When checking multiple OIDs, separate ranges by commas like '-w 1:10,1:,:20'\n\
-- Note that only one string and one regex may be checked at present\n\
-- All evaluation methods other than PR, STR, and SUBSTR expect that the value\n\
-  returned from the SNMP query is an unsigned integer.\n"
-
-#define DESCRIPTION "\
-This plugin gets system information on a remote server via snmp.\n"
-
-#define DEFAULT_COMMUNITY "public"
-#define DEFAULT_PORT "161"
-#define DEFAULT_TIMEOUT 10
-#define DEFAULT_MIBLIST "ALL"
-#define DEFAULT_PROTOCOL "1"
-#define DEFAULT_AUTH_PROTOCOL "MD5"
+const char *revision = "$Revision: 1.53 $";
+const char *copyright = "1999-2004";
+const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
 #include "common.h"
 #include "utils.h"
 #include "popen.h"
 
+#define DEFAULT_COMMUNITY "public"
+#define DEFAULT_PORT "161"
+#define DEFAULT_MIBLIST "ALL"
+#define DEFAULT_PROTOCOL "1"
+#define DEFAULT_TIMEOUT 1
+#define DEFAULT_RETRIES 5
+#define DEFAULT_AUTH_PROTOCOL "MD5"
+#define DEFAULT_DELIMITER "="
+#define DEFAULT_OUTPUT_DELIMITER " "
+
 #define mark(a) ((a)!=0?"*":"")
 
 #define CHECK_UNDEF 0
@@ -147,19 +63,17 @@ This plugin gets system information on a remote server via snmp.\n"
 
 #define MAX_OIDS 8
 #define MAX_DELIM_LENGTH 8
-#define DEFAULT_DELIMITER "="
-#define DEFAULT_OUTPUT_DELIMITER " "
 
-void print_usage (void);
-void print_help (void);
 int process_arguments (int, char **);
 int validate_arguments (void);
-int check_num (int);
 char *clarify_message (char *);
+int check_num (int);
 int lu_getll (unsigned long *, char *);
 int lu_getul (unsigned long *, char *);
 char *thisarg (char *str);
 char *nextarg (char *str);
+void print_usage (void);
+void print_help (void);
 
 #ifdef HAVE_REGEX_H
 #include <regex.h>
@@ -174,7 +88,7 @@ int errcode, excode;
 #endif
 
 char *server_address = NULL;
-char *community = DEFAULT_COMMUNITY;
+char *community = NULL;
 char *authpriv = NULL;
 char *proto = NULL;
 char *seclevel = NULL;
@@ -182,17 +96,17 @@ char *secname = NULL;
 char *authproto = NULL;
 char *authpasswd = NULL;
 char *privpasswd = NULL;
-char *oid = "";
-char *label = "SNMP";
-char *units = "";
-char *port = DEFAULT_PORT;
+char *oid;
+char *label;
+char *units;
+char *port;
 char string_value[MAX_INPUT_BUFFER] = "";
 char **labels = NULL;
 char **unitv = NULL;
-int nlabels = 0;
-int labels_size = 8;
-int nunits = 0;
-int unitv_size = 8;
+size_t nlabels = 0;
+size_t labels_size = 8;
+size_t nunits = 0;
+size_t unitv_size = 8;
 int verbose = FALSE;
 unsigned long lower_warn_lim[MAX_OIDS];
 unsigned long upper_warn_lim[MAX_OIDS];
@@ -201,11 +115,11 @@ unsigned long upper_crit_lim[MAX_OIDS];
 unsigned long response_value[MAX_OIDS];
 int check_warning_value = FALSE;
 int check_critical_value = FALSE;
-int eval_method[MAX_OIDS];
-char *delimiter = DEFAULT_DELIMITER;
-char *output_delim = DEFAULT_OUTPUT_DELIMITER;
-char *miblist = DEFAULT_MIBLIST;
-
+int retries = 0;
+unsigned long eval_method[MAX_OIDS];
+char *delimiter;
+char *output_delim;
+char *miblist;
 
 int
 main (int argc, char **argv)
@@ -217,24 +131,40 @@ main (int argc, char **argv)
 	char input_buffer[MAX_INPUT_BUFFER];
 	char *command_line = NULL;
 	char *response = NULL;
-	char *outbuff = "";
-	char *output = "";
+	char *outbuff;
+	char *output;
 	char *ptr = NULL;
 	char *p2 = NULL;
 	char *show = NULL;
 
+	setlocale (LC_ALL, "");
+	bindtextdomain (PACKAGE, LOCALEDIR);
+	textdomain (PACKAGE);
+
 	labels = malloc (labels_size);
 	unitv = malloc (unitv_size);
 	for (i = 0; i < MAX_OIDS; i++)
 		eval_method[i] = CHECK_UNDEF;
 	i = 0;
 
+	oid = strdup ("");
+	label = strdup ("SNMP");
+	units = strdup ("");
+	port = strdup (DEFAULT_PORT);
+	outbuff = strdup ("");
+	output = strdup ("");
+	delimiter = strdup (DEFAULT_DELIMITER);
+	output_delim = strdup (DEFAULT_OUTPUT_DELIMITER);
+	miblist = strdup (DEFAULT_MIBLIST);
+	timeout_interval = DEFAULT_TIMEOUT;
+	retries = DEFAULT_RETRIES;
+
 	if (process_arguments (argc, argv) == ERROR)
-		usage ("Incorrect arguments supplied\n");
+		usage4 (_("Could not parse arguments"));
 
 	/* create the command line to execute */
-	asprintf (&command_line, "%s -t 1 -r %d -m %s -v %s %s %s:%s %s",
-	          PATH_TO_SNMPGET, timeout_interval - 1, miblist, proto,
+	asprintf (&command_line, "%s -t %d -r %d -m %s -v %s %s %s:%s %s",
+	          PATH_TO_SNMPGET, timeout_interval, retries, miblist, proto,
 	          authpriv, server_address, port, oid);
 	if (verbose)
 		printf ("%s\n", command_line);
@@ -242,13 +172,13 @@ main (int argc, char **argv)
 	/* run the command */
 	child_process = spopen (command_line);
 	if (child_process == NULL) {
-		printf ("Could not open pipe: %s\n", command_line);
+		printf (_("Could not open pipe: %s\n"), command_line);
 		exit (STATE_UNKNOWN);
 	}
 
 	child_stderr = fdopen (child_stderr_array[fileno (child_process)], "r");
 	if (child_stderr == NULL) {
-		printf ("Could not open stderr for %s\n", command_line);
+		printf (_("Could not open stderr for %s\n"), command_line);
 	}
 
 	while (fgets (input_buffer, MAX_INPUT_BUFFER - 1, child_process))
@@ -287,7 +217,7 @@ main (int argc, char **argv)
 				ptr = strpbrk (ptr, "\n");
 			}
 			if (ptr && strstr (ptr, delimiter) == NULL) {
-				response = strscat (response, ptr);
+				asprintf (&response, "%s%s", response, ptr);
 				ptr = NULL;
 			}
 		}
@@ -324,7 +254,7 @@ main (int argc, char **argv)
 		    eval_method[i] & WARN_NE) {
 			p2 = strpbrk (p2, "0123456789");
 			if (p2 == NULL) 
-				terminate (STATE_UNKNOWN,"No valid data returned");
+				die (STATE_UNKNOWN,_("No valid data returned"));
 			response_value[i] = strtoul (p2, NULL, 10);
 			iresult = check_num (i);
 			asprintf (&show, "%lu", response_value[i]);
@@ -332,7 +262,7 @@ main (int argc, char **argv)
 
 		/* Process this block for string matching */
 		else if (eval_method[i] & CRIT_STRING) {
-			if (strcmp (response, string_value))
+			if (strcmp (show, string_value))
 				iresult = STATE_CRITICAL;
 			else
 				iresult = STATE_OK;
@@ -347,14 +277,14 @@ main (int argc, char **argv)
 			}
 			else if (excode != REG_NOMATCH) {
 				regerror (excode, &preg, errbuf, MAX_INPUT_BUFFER);
-				printf ("Execute Error: %s\n", errbuf);
+				printf (_("Execute Error: %s\n"), errbuf);
 				exit (STATE_CRITICAL);
 			}
 			else {
 				iresult = STATE_CRITICAL;
 			}
 #else
-			printf ("%s UNKNOWN: call for regex which was not a compiled option", label);
+			printf (_("Call for regex which was not a compiled option"));
 			exit (STATE_UNKNOWN);
 #endif
 		}
@@ -373,7 +303,7 @@ main (int argc, char **argv)
 		result = max_state (result, iresult);
 
 		/* Prepend a label for this OID if there is one */
-		if (nlabels > 1 && i < nlabels && labels[i] != NULL)
+		if (nlabels > (size_t)1 && (size_t)i < nlabels && labels[i] != NULL)
 			asprintf (&outbuff, "%s%s%s %s%s%s", outbuff,
 			          (i == 0) ? " " : output_delim,
 			          labels[i], mark (iresult), show, mark (iresult));
@@ -382,7 +312,7 @@ main (int argc, char **argv)
 			          mark (iresult), show, mark (iresult));
 
 		/* Append a unit string for this OID if there is one */
-		if (nunits > 0 && i < nunits && unitv[i] != NULL)
+		if (nunits > (size_t)0 && (size_t)i < nunits && unitv[i] != NULL)
 			asprintf (&outbuff, "%s %s", outbuff, unitv[i]);
 
 		i++;
@@ -390,10 +320,10 @@ main (int argc, char **argv)
 	}															/* end while (ptr) */
 
 	if (found == 0)
-		terminate
-			(STATE_UNKNOWN,
-			 "%s problem - No data recieved from host\nCMD: %s\n",
-			 label, command_line);
+		die (STATE_UNKNOWN,
+		     _("%s problem - No data received from host\nCMD: %s\n"),
+		     label,
+		     command_line);
 
 	/* WARNING if output found on stderr */
 	if (fgets (input_buffer, MAX_INPUT_BUFFER - 1, child_stderr))
@@ -414,6 +344,8 @@ main (int argc, char **argv)
 	return result;
 }
 
+
+
 /* process command-line arguments */
 int
 process_arguments (int argc, char **argv)
@@ -422,9 +354,8 @@ process_arguments (int argc, char **argv)
 	int c = 1;
 	int j = 0, jj = 0, ii = 0;
 
-#ifdef HAVE_GETOPT_H
-	int option_index = 0;
-	static struct option long_options[] = {
+	int option = 0;
+	static struct option longopts[] = {
 		STD_LONG_OPTS,
 		{"community", required_argument, 0, 'C'},
 		{"oid", required_argument, 0, 'o'},
@@ -432,12 +363,14 @@ process_arguments (int argc, char **argv)
 		{"delimiter", required_argument, 0, 'd'},
 		{"output-delimiter", required_argument, 0, 'D'},
 		{"string", required_argument, 0, 's'},
+		{"timeout", required_argument, 0, 't'},
 		{"regex", required_argument, 0, 'r'},
 		{"ereg", required_argument, 0, 'r'},
 		{"eregi", required_argument, 0, 'R'},
 		{"label", required_argument, 0, 'l'},
 		{"units", required_argument, 0, 'u'},
 		{"port", required_argument, 0, 'p'},
+		{"retries", required_argument, 0, 'e'},
 		{"miblist", required_argument, 0, 'm'},
 		{"protocol", required_argument, 0, 'P'},
 		{"seclevel", required_argument, 0, 'L'},
@@ -447,7 +380,6 @@ process_arguments (int argc, char **argv)
 		{"privpasswd", required_argument, 0, 'X'},
 		{0, 0, 0, 0}
 	};
-#endif
 
 	if (argc < 2)
 		return ERROR;
@@ -463,25 +395,20 @@ process_arguments (int argc, char **argv)
 	}
 
 	while (1) {
-#ifdef HAVE_GETOPT_H
-		c =
-			getopt_long (argc, argv, "hvVt:c:w:H:C:o:e:E:d:D:s:R:r:l:u:p:m:P:L:U:a:A:X:",
-									 long_options, &option_index);
-#else
-		c = getopt (argc, argv, "hvVt:c:w:H:C:o:e:E:d:D:s:R:r:l:u:p:m:P:L:U:a:A:X:");
-#endif
+		c = getopt_long (argc, argv, "hvVt:c:w:H:C:o:e:E:d:D:s:t:R:r:l:u:p:m:P:L:U:a:A:X:",
+									 longopts, &option);
 
 		if (c == -1 || c == EOF)
 			break;
 
 		switch (c) {
 		case '?':	/* usage */
-			usage3 ("Unknown argument", optopt);
+			usage2 (_("Unknown argument"), optarg);
 		case 'h':	/* help */
 			print_help ();
 			exit (STATE_OK); 
 		case 'V':	/* version */
-			print_revision (progname, REVISION);
+			print_revision (progname, revision);
 			exit (STATE_OK);
 		case 'v': /* verbose */
 			verbose = TRUE;
@@ -489,48 +416,46 @@ process_arguments (int argc, char **argv)
 
 	/* Connection info */
 		case 'C':									/* group or community */
-			community = strscpy (community, optarg);
+			community = optarg;
 			break;
 		case 'H':									/* Host or server */
-			server_address = strscpy (server_address, optarg);
+			server_address = optarg;
 			break;
 		case 'p':       /* TCP port number */
-			port = strscpy(port, optarg);
+			port = optarg;
 			break;
 		case 'm':      /* List of MIBS  */
-			miblist = strscpy(miblist, optarg);
+			miblist = optarg;
 			break;
 		case 'P':     /* SNMP protocol version */
-			proto = strscpy(proto, optarg);
+			proto = optarg;
 			break;
 		case 'L':     /* security level */
-			seclevel = strscpy(seclevel,optarg);
+			seclevel = optarg;
 			break;
 		case 'U':     /* security username */
-			secname = strscpy(secname, optarg);
+			secname = optarg;
 			break;
 		case 'a':     /* auth protocol */
-			asprintf (&authproto, optarg);
+			authproto = optarg;
 			break;
 		case 'A':     /* auth passwd */
-			authpasswd = strscpy(authpasswd, optarg);
+			authpasswd = optarg;
 			break;
 		case 'X':     /* priv passwd */
-			privpasswd = strscpy(privpasswd, optarg);
+			privpasswd = optarg;
 			break;
 		case 't':	/* timeout period */
 			if (!is_integer (optarg))
-				usage2 ("Timeout Interval must be an integer", optarg);
-			timeout_interval = atoi (optarg);
+				usage2 (_("Timeout interval must be a positive integer"), optarg);
+			else
+				timeout_interval = atoi (optarg);
 			break;
 
 	/* Test parameters */
 		case 'c':									/* critical time threshold */
-			if (strspn (optarg, "0123456789:,") < strlen (optarg)) {
-				printf ("Invalid critical threshold: %s\n", optarg);
-				print_usage ();
-				exit (STATE_UNKNOWN);
-			}
+			if (strspn (optarg, "0123456789:,") < strlen (optarg))
+				usage2 (_("Invalid critical threshold: %s\n"), optarg);
 			for (ptr = optarg; ptr && jj < MAX_OIDS; jj++) {
 				if (lu_getll (&lower_crit_lim[jj], ptr) == 1)
 					eval_method[jj] |= CRIT_LT;
@@ -540,11 +465,8 @@ process_arguments (int argc, char **argv)
 			}
 			break;
 		case 'w':									/* warning time threshold */
-			if (strspn (optarg, "0123456789:,") < strlen (optarg)) {
-				printf ("Invalid warning threshold: %s\n", optarg);
-				print_usage ();
-				exit (STATE_UNKNOWN);
-			}
+			if (strspn (optarg, "0123456789:,") < strlen (optarg))
+				usage2 (_("Invalid warning threshold: %s\n"), optarg);
 			for (ptr = optarg; ptr && ii < MAX_OIDS; ii++) {
 				if (lu_getll (&lower_warn_lim[ii], ptr) == 1)
 					eval_method[ii] |= WARN_LT;
@@ -553,9 +475,14 @@ process_arguments (int argc, char **argv)
 				(ptr = index (ptr, ',')) ? ptr++ : ptr;
 			}
 			break;
-		case 'o':									/* object identifier */
 		case 'e': /* PRELIMINARY - may change */
 		case 'E': /* PRELIMINARY - may change */
+			if (!is_integer (optarg))
+				usage2 (_("Retries interval must be a positive integer"), optarg);
+			else
+				retries = atoi(optarg);
+			break;
+		case 'o':									/* object identifier */
 			for (ptr = optarg; (ptr = index (ptr, ',')); ptr++)
 				ptr[0] = ' '; /* relpace comma with space */
 			for (ptr = optarg; (ptr = index (ptr, ' ')); ptr++)
@@ -588,13 +515,13 @@ process_arguments (int argc, char **argv)
 			errcode = regcomp (&preg, regex_expect, cflags);
 			if (errcode != 0) {
 				regerror (errcode, &preg, errbuf, MAX_INPUT_BUFFER);
-				printf ("Could Not Compile Regular Expression");
+				printf (_("Could Not Compile Regular Expression"));
 				return ERROR;
 			}
 			eval_method[jj++] = CRIT_REGEX;
 			ii++;
 #else
-			printf ("%s UNKNOWN: call for regex which was not a compiled option", label);
+			printf (_("call for regex which was not a compiled option"));
 			exit (STATE_UNKNOWN);
 #endif
 			break;
@@ -613,21 +540,19 @@ process_arguments (int argc, char **argv)
 				labels_size += 8;
 				labels = realloc (labels, labels_size);
 				if (labels == NULL)
-					terminate (STATE_UNKNOWN,
-										 "Could not realloc() labels[%d]", nlabels);
+					die (STATE_UNKNOWN, _("Could not reallocate labels[%d]"), nlabels);
 			}
 			labels[nlabels - 1] = optarg;
 			ptr = thisarg (optarg);
+			labels[nlabels - 1] = ptr;
 			if (strstr (ptr, "'") == ptr)
 				labels[nlabels - 1] = ptr + 1;
-			else
-				labels[nlabels - 1] = ptr;
 			while (ptr && (ptr = nextarg (ptr))) {
 				if (nlabels >= labels_size) {
 					labels_size += 8;
 					labels = realloc (labels, labels_size);
 					if (labels == NULL)
-						terminate (STATE_UNKNOWN, "Could not realloc() labels\n");
+						die (STATE_UNKNOWN, _("Could not reallocate labels\n"));
 				}
 				labels++;
 				ptr = thisarg (ptr);
@@ -644,21 +569,19 @@ process_arguments (int argc, char **argv)
 				unitv_size += 8;
 				unitv = realloc (unitv, unitv_size);
 				if (unitv == NULL)
-					terminate (STATE_UNKNOWN,
-										 "Could not realloc() units [%d]\n", nunits);
+					die (STATE_UNKNOWN, _("Could not reallocate units [%d]\n"), nunits);
 			}
 			unitv[nunits - 1] = optarg;
 			ptr = thisarg (optarg);
+			unitv[nunits - 1] = ptr;
 			if (strstr (ptr, "'") == ptr)
 				unitv[nunits - 1] = ptr + 1;
-			else
-				unitv[nunits - 1] = ptr;
 			while (ptr && (ptr = nextarg (ptr))) {
 				if (nunits >= unitv_size) {
 					unitv_size += 8;
 					unitv = realloc (unitv, unitv_size);
 					if (units == NULL)
-						terminate (STATE_UNKNOWN, "Could not realloc() units\n");
+						die (STATE_UNKNOWN, _("Could not realloc() units\n"));
 				}
 				nunits++;
 				ptr = thisarg (ptr);
@@ -673,11 +596,15 @@ process_arguments (int argc, char **argv)
 	}
 
 	if (server_address == NULL)
-		asprintf (&server_address, argv[optind]);
+		server_address = argv[optind];
+
+	if (community == NULL)
+		community = strdup (DEFAULT_COMMUNITY);
 
 	return validate_arguments ();
 }
 
+
 /******************************************************************************
 
 @@-
@@ -698,6 +625,8 @@ first character cannot be a number, however.</para>
 -@@
 ******************************************************************************/
 
+
+
 int
 validate_arguments ()
 {
@@ -725,7 +654,7 @@ validate_arguments ()
 		}
 		else if ( strcmp(seclevel, "authNoPriv") == 0 ) {
 			if ( secname == NULL || authpasswd == NULL) {
-				printf ("Missing secname (%s) or authpassword (%s) ! \n",secname, authpasswd );
+				printf (_("Missing secname (%s) or authpassword (%s) ! \n"),secname, authpasswd );
 				print_usage ();
 				exit (STATE_UNKNOWN);
 			}
@@ -733,54 +662,23 @@ validate_arguments ()
 		}
 		else if ( strcmp(seclevel, "authPriv") == 0 ) {
 			if ( secname == NULL || authpasswd == NULL || privpasswd == NULL ) {
-				printf ("Missing secname (%s), authpassword (%s), or privpasswd (%s)! \n",secname, authpasswd,privpasswd );
+				printf (_("Missing secname (%s), authpassword (%s), or privpasswd (%s)! \n"),secname, authpasswd,privpasswd );
 				print_usage ();
 				exit (STATE_UNKNOWN);
 			}
 			asprintf(&authpriv, "-l authPriv -a %s -u %s -A %s -x DES -X %s ", authproto, secname, authpasswd, privpasswd);
 		}
 		
-									
 	}
 	else {
-		printf ("Invalid SNMP version: %s\n", proto);
-		print_usage ();
-		exit (STATE_UNKNOWN);				
+		usage2 (_("Invalid SNMP version"), proto);
 	}
 			
-	
-	
-
 	return OK;
 }
 
 
 
-void
-print_help (void)
-{
-	print_revision (progname, REVISION);
-	printf
-		("Copyright (c) %s %s <%s>\n\n%s\n", COPYRIGHT, AUTHOR, EMAIL, SUMMARY);
-	print_usage ();
-	printf
-		("\nOptions:\n" LONGOPTIONS "\n" DESCRIPTION "\n" NOTES "\n", 
-		 DEFAULT_COMMUNITY, DEFAULT_PORT, DEFAULT_DELIMITER, DEFAULT_TIMEOUT);
-	support ();
-}
-
-void
-print_usage (void)
-{
-	printf
-		("Usage:\n" " %s %s\n"
-		 " %s (-h | --help) for detailed help\n"
-		 " %s (-V | --version) for version information\n",
-		 progname, OPTIONS, progname, progname);
-}
-
-
-
 char *
 clarify_message (char *msg)
 {
@@ -817,6 +715,7 @@ clarify_message (char *msg)
 }
 
 
+
 int
 check_num (int i)
 {
@@ -840,7 +739,7 @@ check_num (int i)
 	}
 
 	if (eval_method[i] & CRIT_GT && eval_method[i] & CRIT_LT &&
-			lower_warn_lim[i] > upper_warn_lim[i]) {
+			lower_crit_lim[i] > upper_crit_lim[i]) {
 		if (response_value[i] <= lower_crit_lim[i] &&
 				response_value[i] >= upper_crit_lim[i]) {
 			result = STATE_CRITICAL;
@@ -860,6 +759,7 @@ check_num (int i)
 }
 
 
+
 int
 lu_getll (unsigned long *ll, char *str)
 {
@@ -873,6 +773,8 @@ lu_getll (unsigned long *ll, char *str)
 	return 0;
 }
 
+
+
 int
 lu_getul (unsigned long *ul, char *str)
 {
@@ -888,9 +790,6 @@ lu_getul (unsigned long *ul, char *str)
 
 
 
-
-
-
 /* trim leading whitespace
 	 if there is a leading quote, make sure it balances */
 
@@ -900,12 +799,13 @@ thisarg (char *str)
 	str += strspn (str, " \t\r\n");	/* trim any leading whitespace */
 	if (strstr (str, "'") == str) {	/* handle SIMPLE quoted strings */
 		if (strlen (str) == 1 || !strstr (str + 1, "'"))
-			terminate (STATE_UNKNOWN, "Unbalanced quotes\n");
+			die (STATE_UNKNOWN, _("Unbalanced quotes\n"));
 	}
 	return str;
 }
 
 
+
 /* if there's a leading quote, advance to the trailing quote
 	 set the trailing quote to '\x0'
 	 if the string continues, advance beyond the comma */
@@ -914,23 +814,21 @@ char *
 nextarg (char *str)
 {
 	if (strstr (str, "'") == str) {
+		str[0] = 0;
 		if (strlen (str) > 1) {
 			str = strstr (str + 1, "'");
-			str[0] = 0;
 			return (++str);
 		}
 		else {
-			str[0] = 0;
 			return NULL;
 		}
 	}
 	if (strstr (str, ",") == str) {
+		str[0] = 0;
 		if (strlen (str) > 1) {
-			str[0] = 0;
 			return (++str);
 		}
 		else {
-			str[0] = 0;
 			return NULL;
 		}
 	}
@@ -940,3 +838,126 @@ nextarg (char *str)
 	}
 	return NULL;
 }
+
+
+
+void
+print_help (void)
+{
+	print_revision (progname, revision);
+
+	printf (COPYRIGHT, copyright, email);
+
+	printf (_("\
+Check status of remote machines and obtain sustem information via SNMP\n\n"));
+
+	print_usage ();
+
+	printf (_(UT_HELP_VRSN));
+
+	printf (_(UT_HOST_PORT), 'p', DEFAULT_PORT);
+
+	/* SNMP and Authentication Protocol */
+	printf (_("\
+ -P, --protocol=[1|3]\n\
+    SNMP protocol version\n\
+ -L, --seclevel=[noAuthNoPriv|authNoPriv|authPriv]\n\
+    SNMPv3 securityLevel\n\
+ -a, --authproto=[MD5|SHA]\n\
+    SNMPv3 auth proto\n"));
+
+	/* Authentication Tokens*/
+	printf (_("\
+ -C, --community=STRING\n\
+    Optional community string for SNMP communication\n\
+    (default is \"%s\")\n\
+ -U, --secname=USERNAME\n\
+    SNMPv3 username\n\
+ -A, --authpassword=PASSWORD\n\
+    SNMPv3 authentication password\n\
+ -X, --privpasswd=PASSWORD\n\
+    SNMPv3 crypt passwd (DES)\n"), DEFAULT_COMMUNITY);
+
+	/* OID Stuff */
+	printf (_("\
+ -o, --oid=OID(s)\n\
+    Object identifier(s) whose value you wish to query\n\
+ -m, --miblist=STRING\n\
+    List of MIBS to be loaded (default = ALL)\n -d, --delimiter=STRING\n\
+    Delimiter to use when parsing returned data. Default is \"%s\"\n\
+    Any data on the right hand side of the delimiter is considered\n\
+    to be the data that should be used in the evaluation.\n"), DEFAULT_DELIMITER);
+
+	/* Tests Against Integers */
+	printf (_("\
+ -w, --warning=INTEGER_RANGE(s)\n\
+    Range(s) which will not result in a WARNING status\n\
+ -c, --critical=INTEGER_RANGE(s)\n\
+    Range(s) which will not result in a CRITICAL status\n"));
+
+	/* Tests Against Strings */
+	printf (_("\
+ -s, --string=STRING\n\
+    Return OK state (for that OID) if STRING is an exact match\n\
+ -r, --ereg=REGEX\n\
+    Return OK state (for that OID) if extended regular expression REGEX matches\n\
+ -R, --eregi=REGEX\n\
+    Return OK state (for that OID) if case-insensitive extended REGEX matches\n\
+ -l, --label=STRING\n\
+    Prefix label for output from plugin (default -s 'SNMP')\n"));
+
+	/* Output Formatting */
+	printf (_("\
+ -u, --units=STRING\n\
+    Units label(s) for output data (e.g., 'sec.').\n\
+ -D, --output-delimiter=STRING\n\
+    Separates output on multiple OID requests\n"));
+
+	printf (_(UT_TIMEOUT), DEFAULT_SOCKET_TIMEOUT);
+
+	printf (_(UT_VERBOSE));
+
+	printf (_("\n\
+- This plugin uses the 'snmpget' command included with the NET-SNMP package.\n\
+  If you don't have the package installed, you will need to download it from\n\
+  http://net-snmp.sourceforge.net before you can use this plugin.\n"));
+
+	printf (_("\
+- Multiple OIDs may be indicated by a comma- or space-delimited list (lists with\n\
+  internal spaces must be quoted) [max 8 OIDs]\n"));
+
+	printf (_("\
+- Ranges are inclusive and are indicated with colons. When specified as\n\
+  'min:max' a STATE_OK will be returned if the result is within the indicated\n\
+  range or is equal to the upper or lower bound. A non-OK state will be\n\
+  returned if the result is outside the specified range.\n"));
+
+	printf (_("\
+- If specified in the order 'max:min' a non-OK state will be returned if the\n\
+  result is within the (inclusive) range.\n"));
+
+	printf (_("\
+- Upper or lower bounds may be omitted to skip checking the respective limit.\n\
+- Bare integers are interpreted as upper limits.\n\
+- When checking multiple OIDs, separate ranges by commas like '-w 1:10,1:,:20'\n\
+- Note that only one string and one regex may be checked at present\n\
+- All evaluation methods other than PR, STR, and SUBSTR expect that the value\n\
+  returned from the SNMP query is an unsigned integer.\n"));
+
+	printf (_(UT_SUPPORT));
+}
+
+
+
+void
+print_usage (void)
+{
+	printf ("\
+Usage: %s -H <ip_address> -o <OID> [-w warn_range] [-c crit_range] \n\
+                  [-C community] [-s string] [-r regex] [-R regexi]\n\
+                  [-t timeout] [-e retries]\n\
+                  [-l label] [-u units] [-p port-number] [-d delimiter]\n\
+                  [-D output-delimiter] [-m miblist] [-P snmp version]\n\
+                  [-L seclevel] [-U secname] [-a authproto] [-A authpasswd]\n\
+                  [-X privpasswd]\n", progname);
+}
