@@ -7,53 +7,22 @@
  * Copyright (c) 2000 Karl DeBisschop (karl@debisschop.net)
  * License: GPL
  *
- * $Revision: 1.16.2.1 $
- * $Date: 2003/04/23 04:57:08 $
+ * $Revision: 1.41 $
+ * $Date: 2004/12/25 23:17:44 $
  ****************************************************************************/
 
-#include "config.h"
+#define LOCAL_TIMEOUT_ALARM_HANDLER
+
 #include "common.h"
-#include "version.h"
+#include "utils.h"
 #include <stdarg.h>
 #include <limits.h>
 
-extern int timeout_interval;
+#include <arpa/inet.h>
+
+extern void print_usage (void);
 extern const char *progname;
 
-void support (void);
-char *clean_revstring (const char *);
-void print_revision (const char *, const char *);
-void terminate (int, const char *fmt, ...);
-RETSIGTYPE timeout_alarm_handler (int);
-
-int is_host (char *);
-int is_dotted_quad (char *);
-int is_hostname (char *);
-
-int is_integer (char *);
-int is_intpos (char *);
-int is_intneg (char *);
-int is_intnonneg (char *);
-int is_intpercent (char *);
-
-int is_numeric (char *);
-int is_positive (char *);
-int is_negative (char *);
-int is_nonnegative (char *);
-int is_percentage (char *);
-
-int is_option (char *str);
-
-double delta_time (struct timeval tv);
-
-void strip (char *);
-char *strscpy (char *dest, const char *src);
-char *strscat (char *dest, char *src);
-char *strnl (char *str);
-char *strpcpy (char *dest, const char *src, const char *str);
-char *strpcat (char *dest, const char *src, const char *str);
-
-#define LABELLEN 63
 #define STRLEN 64
 #define TXTBLK 128
 
@@ -65,8 +34,6 @@ char *strpcat (char *dest, const char *src, const char *str);
  * Note that numerically the above does not hold
  ****************************************************************************/
 
-#define max(a,b) (((a)>(b))?(a):(b))
-
 int
 max_state (int a, int b)
 {
@@ -84,14 +51,14 @@ max_state (int a, int b)
 		return max (a, b);
 }
 
-void usage (char *msg)
+void usage (const char *msg)
 {
-	printf (msg);
+	printf ("%s\n", msg);
 	print_usage ();
 	exit (STATE_UNKNOWN);
 }
 
-void usage2(char *msg, char *arg)
+void usage2(const char *msg, const char *arg)
 {
 	printf ("%s: %s - %s\n",progname,msg,arg);
 	print_usage ();
@@ -99,24 +66,21 @@ void usage2(char *msg, char *arg)
 }
 
 void
-usage3 (char *msg, char arg)
+usage3 (const char *msg, int arg)
 {
 	printf ("%s: %s - %c\n", progname, msg, arg);
 	print_usage();
 	exit (STATE_UNKNOWN);
 }
 
-
 void
-support (void)
+usage4 (const char *msg)
 {
-	printf
-		("Send email to nagios-users@lists.sourceforge.net if you have questions\n"
-		 "regarding use of this software. To submit patches or suggest improvements,\n"
-		 "send email to nagiosplug-devel@lists.sourceforge.net\n");
+	printf ("%s: %s\n", progname, msg);
+	print_usage();
+	exit (STATE_UNKNOWN);
 }
 
-
 char *
 clean_revstring (const char *revstring)
 {
@@ -134,18 +98,29 @@ print_revision (const char *command_name, const char *revision_string)
 
 	if (sscanf (revision_string, "$Revision: %[0-9.]", plugin_revision) != 1)
 		strncpy (plugin_revision, "N/A", STRLEN);
-	printf ("%s (nagios-plugins %s) %s\n",
-					progname, VERSION, plugin_revision);
-	printf
-		("The nagios plugins come with ABSOLUTELY NO WARRANTY. You may redistribute\n"
-		 "copies of the plugins under the terms of the GNU General Public License.\n"
-		 "For more information about these matters, see the file named COPYING.\n");
-
+	printf ("%s (%s %s) %s\n",
+					command_name, PACKAGE, VERSION, plugin_revision);
 }
 
+const char *
+state_text (int result)
+{
+	switch (result) {
+	case STATE_OK:
+		return "OK";
+	case STATE_WARNING:
+		return "WARNING";
+	case STATE_CRITICAL:
+		return "CRITICAL";
+	case STATE_DEPENDENT:
+		return "DEPENDENT";
+	default:
+		return "UNKNOWN";
+	}
+}
 
 void
-terminate (int result, const char *fmt, ...)
+die (int result, const char *fmt, ...)
 {
 	va_list ap;
 	va_start (ap, fmt);
@@ -158,84 +133,12 @@ void
 timeout_alarm_handler (int signo)
 {
 	if (signo == SIGALRM) {
-		printf ("CRITICAL - Plugin timed out after %d seconds\n",
+		printf (_("CRITICAL - Plugin timed out after %d seconds\n"),
 						timeout_interval);
 		exit (STATE_CRITICAL);
 	}
 }
 
-int
-is_host (char *address)
-{
-	if (is_dotted_quad (address) || is_hostname (address))
-		return (TRUE);
-	return (FALSE);
-}
-
-int
-is_dotted_quad (char *address)
-{
-	int o1, o2, o3, o4;
-	char c[1];
-
-	if (!address)
-		return FALSE;
-
-	if (sscanf (address, "%d.%d.%d.%d%c", &o1, &o2, &o3, &o4, c) != 4)
-		return FALSE;
-	else if (o1 > 255 || o2 > 255 || o3 > 255 || o4 > 255)
-		return FALSE;
-	else if (o1 < 0 || o2 < 0 || o3 < 0 || o4 < 0)
-		return FALSE;
-	else
-		return TRUE;
-}
-
-/* from RFC-1035
-* 
-* The labels must follow the rules for ARPANET host names.  They must
-* start with a letter, end with a letter or digit, and have as interior
-* characters only letters, digits, and hyphen.  There are also some
-* restrictions on the length.  Labels must be 63 characters or less.
-*
-* Then RFC-1123:
-*
-*  2.1  Host Names and Numbers
-*
-*    The syntax of a legal Internet host name was specified in RFC-952
-*    [DNS:4].  One aspect of host name syntax is hereby changed: the
-*    restriction on the first character is relaxed to allow either a
-*    letter or a digit.  Host software MUST support this more liberal
-*    syntax.
-*
-*    Host software MUST handle host names of up to 63 characters and
-*    SHOULD handle host names of up to 255 characters.
-*/
-
-int
-is_hostname (char *s1)
-{
-	if (!s1 || strlen (s1) > 255) {
-		return FALSE;
-	}
-	/* if s1 contains anything but ALPHA, NUM, dash, or period*/
-	if (strcspn (s1, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUWVXYZ0123456789-.") !=	0) {
-		return FALSE;
-	}
-	/* or if s1 begins with dash or period */
-	if (strspn (s1, "-.") == 1) {
-		return FALSE;
-	}
-  /* '..' and '.-' are not legal either */
-	while ((s1 = index (s1, '.'))) {
-		s1++;
-		if (strspn (s1, "0123456789-.") == 1) {
-			return FALSE;
-		}
-	}
-	return TRUE;
-}
-
 int
 is_numeric (char *number)
 {
@@ -375,6 +278,16 @@ delta_time (struct timeval tv)
 
 
 
+long
+deltime (struct timeval tv)
+{
+	struct timeval now;
+	gettimeofday (&now, NULL);
+	return (now.tv_sec - tv.tv_sec)*1000000 + now.tv_usec - tv.tv_usec;
+}
+
+
+
 
 void
 strip (char *buffer)
@@ -394,9 +307,6 @@ strip (char *buffer)
 }
 
 
-
-
-
 /******************************************************************************
  *
  * Copies one string to another. Any previously existing data in
@@ -422,42 +332,6 @@ strscpy (char *dest, const char *src)
 
 
 
-
-
-/******************************************************************************
- *
- * Concatenates one string to the end of another
- *
- * Given a pointer destination string, which may or may not already
- * hold some text, and a source string with additional text (possibly
- * NULL or empty), returns a pointer to a string that is the first
- * string with the second concatenated to it. Uses realloc to free 
- * memory held by the dest argument if new storage space is required.
- *
- * Example:
- *
- * char *str=NULL;
- * str = strscpy("This is a line of text with no trailing newline");
- * str = strscat(str,"\n");
- *
- *****************************************************************************/
-
-char *
-strscat (char *dest, char *src)
-{
-
-	if (dest == NULL)
-		return src;
-	if (src != NULL)
-		asprintf (&dest, "%s%s", dest, src);
-
-	return dest;
-}
-
-
-
-
-
 /******************************************************************************
  *
  * Returns a pointer to the next line of a multiline string buffer
@@ -527,9 +401,6 @@ strnl (char *str)
 }
 
 
-
-
-
 /******************************************************************************
  *
  * Like strscpy, except only the portion of the source string up to
@@ -559,7 +430,7 @@ strpcpy (char *dest, const char *src, const char *str)
 	if (dest == NULL || strlen (dest) < len)
 		dest = realloc (dest, len + 1);
 	if (dest == NULL)
-		terminate (STATE_UNKNOWN, "failed realloc in strpcpy\n");
+		die (STATE_UNKNOWN, _("failed realloc in strpcpy\n"));
 
 	strncpy (dest, src, len);
 	dest[len] = '\0';
@@ -569,8 +440,6 @@ strpcpy (char *dest, const char *src, const char *str)
 
 
 
-
-
 /******************************************************************************
  *
  * Like strscat, except only the portion of the source string up to
@@ -603,10 +472,99 @@ strpcat (char *dest, const char *src, const char *str)
 
 	dest = realloc (dest, len + l2 + 1);
 	if (dest == NULL)
-		terminate (STATE_UNKNOWN, "failed malloc in strscat\n");
+		die (STATE_UNKNOWN, _("failed malloc in strscat\n"));
 
 	strncpy (dest + len, src, l2);
 	dest[len + l2] = '\0';
 
 	return dest;
 }
+
+
+/******************************************************************************
+ *
+ * Print perfdata in a standard format
+ *
+ ******************************************************************************/
+
+char *perfdata (const char *label,
+ long int val,
+ const char *uom,
+ int warnp,
+ long int warn,
+ int critp,
+ long int crit,
+ int minp,
+ long int minv,
+ int maxp,
+ long int maxv)
+{
+	char *data = NULL;
+
+	if (strpbrk (label, "'= "))
+		asprintf (&data, "'%s'=%ld%s;", label, val, uom);
+	else
+		asprintf (&data, "%s=%ld%s;", label, val, uom);
+
+	if (warnp)
+		asprintf (&data, "%s%ld;", data, warn);
+	else
+		asprintf (&data, "%s;", data);
+
+	if (critp)
+		asprintf (&data, "%s%ld;", data, crit);
+	else
+		asprintf (&data, "%s;", data);
+
+	if (minp)
+		asprintf (&data, "%s%ld", data, minv);
+
+	if (maxp)
+		asprintf (&data, "%s;%ld", data, maxv);
+
+	return data;
+}
+
+
+char *fperfdata (const char *label,
+ double val,
+ const char *uom,
+ int warnp,
+ double warn,
+ int critp,
+ double crit,
+ int minp,
+ double minv,
+ int maxp,
+ double maxv)
+{
+	char *data = NULL;
+
+	if (strpbrk (label, "'= "))
+		asprintf (&data, "'%s'=", label);
+	else
+		asprintf (&data, "%s=", label);
+
+	asprintf (&data, "%s%f", data, val);
+	asprintf (&data, "%s%s;", data, uom);
+
+	if (warnp)
+		asprintf (&data, "%s%f", data, warn);
+
+	asprintf (&data, "%s;", data);
+
+	if (critp)
+		asprintf (&data, "%s%f", data, crit);
+
+	asprintf (&data, "%s;", data);
+
+	if (minp)
+		asprintf (&data, "%s%f", data, minv);
+
+	if (maxp) {
+		asprintf (&data, "%s;", data);
+		asprintf (&data, "%s%f", data, maxv);
+	}
+
+	return data;
+}
